@@ -1,17 +1,31 @@
 /*
- * $Id: acl.c,v 1.12.2.26 1996/07/01 21:59:54 wessels Exp $
+ * $Id: acl.c,v 1.12.2.29 1996/07/08 18:30:47 wessels Exp $
  *
- * DEBUG: section 28	Access Control
+ * DEBUG: section 28    Access Control
  * AUTHOR: Duane Wessels
  *
  * SQUID Internet Object Cache  http://www.nlanr.net/Squid/
  * --------------------------------------------------------
  *
- *   Squid is a result of efforts by numerous individuals from the
- *   Internet community.  Development is led by Duane Wessels of the
- *   National Laboratory for Applied Network Research and funded by
- *   the National Science Foundation.
- * 
+ *  Squid is the result of efforts by numerous individuals from the
+ *  Internet community.  Development is led by Duane Wessels of the
+ *  National Laboratory for Applied Network Research and funded by
+ *  the National Science Foundation.
+ *
+ *  This program is free software; you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation; either version 2 of the License, or
+ *  (at your option) any later version.
+ *  
+ *  This program is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *  
+ *  You should have received a copy of the GNU General Public License
+ *  along with this program; if not, write to the Free Software
+ *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ *  
  */
 
 #include "squid.h"
@@ -40,9 +54,9 @@ static intlist *aclParseProtoList _PARAMS((void));
 static struct _relist *aclParseRegexList _PARAMS((void));
 static struct _acl_time_data *aclParseTimeSpec _PARAMS((void));
 static wordlist *aclParseWordList _PARAMS((void));
-static acl_t aclType _PARAMS((char *s));
+static squid_acl aclType _PARAMS((char *s));
 
-static acl_t aclType(s)
+static squid_acl aclType(s)
      char *s;
 {
     if (!strcmp(s, "src"))
