@@ -1,6 +1,6 @@
 
 /*
- * $Id: ssl.c,v 1.1.2.22 1996/07/15 16:15:03 wessels Exp $
+ * $Id: ssl.c,v 1.1.2.23 1996/07/24 17:03:09 wessels Exp $
  *
  * DEBUG: section 26    Secure Sockets Layer Proxy
  * AUTHOR: Duane Wessels
@@ -356,7 +356,7 @@ static int sslConnect(fd, hp, sslState)
     request_t *request = sslState->request;
     int status;
     char *buf = NULL;
-    if (!ipcache_gethostbyname(request->host, 0)) {
+    if (hp == NULL) {
 	debug(26, 4, "sslConnect: Unknown host: %s\n", request->host);
 	buf = squid_error_url(sslState->url,
 	    request->method,
